<?php

namespace Provider\Package\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Provider\Package\Interfaces\ModuleNameRepositoryInterface;

class ModuleNamePublicController extends BaseController
{
    // use ModuleNameWorkflow;

    /**
     * Constructor.
     *
     * @param type \Provider\ModuleName\Interfaces\ModuleNameRepositoryInterface $module_name
     *
     * @return type
     */
    public function __construct(ModuleNameRepositoryInterface $module_name)
    {
        $this->repository = $module_name;
        parent::__construct();
    }

    /**
     * Show module_name's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $module_names = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$package::$module_name.names'))
            ->view('$package::public.module_name.index')
            ->data(compact('$module_names'))
            ->output();
    }

    /**
     * Show module_name's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $module_names = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$package::$module_name.names'))
            ->view('$package::public.module_name.index')
            ->data(compact('$module_names'))
            ->output();
    }

    /**
     * Show module_name.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $module_name = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$module_name->name . trans('$package::$module_name.name'))
            ->view('$package::public.module_name.show')
            ->data(compact('$module_name'))
            ->output();
    }

}
