<?php

namespace Provider\Package\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Provider\Package\Http\Requests\ModuleNameRequest;
use Provider\Package\Models\ModuleName;

/**
 * Admin web controller class.
 */
class ModuleNameWorkflowController extends BaseController
{

    /**
     * Workflow controller function for module_name.
     *
     * @param Model   $module_name
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ModuleNameRequest $request, ModuleName $module_name, $step)
    {

        try {

            $module_name->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('package::module_name.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/module_name/module_name/' . $module_name->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/module_name/module_name/' . $module_name->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for module_name.
     *
     * @param Model   $module_name
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(ModuleName $module_name, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $module_name->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('package::module_name.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('package::admin.module_name.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('package::admin.module_name.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('package::admin.module_name.message', $data)->render();

        }

    }
}
