<?php

namespace Provider\Package\Policies;

use Litepie\User\Contracts\UserPolicy;
use Provider\Package\Models\ModuleName;

class ModuleNamePolicy
{

    /**
     * Determine if the given user can view the module_name.
     *
     * @param UserPolicy $user
     * @param ModuleName $module_name
     *
     * @return bool
     */
    public function view(UserPolicy $user, ModuleName $module_name)
    {
        if ($user->canDo('package.module_name.view') && $user->isAdmin()) {
            return true;
        }

        return $module_name->user_id == user_id() && $module_name->user_type == user_type();
    }

    /**
     * Determine if the given user can create a module_name.
     *
     * @param UserPolicy $user
     * @param ModuleName $module_name
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('package.module_name.create');
    }

    /**
     * Determine if the given user can update the given module_name.
     *
     * @param UserPolicy $user
     * @param ModuleName $module_name
     *
     * @return bool
     */
    public function update(UserPolicy $user, ModuleName $module_name)
    {
        if ($user->canDo('package.module_name.edit') && $user->isAdmin()) {
            return true;
        }

        return $module_name->user_id == user_id() && $module_name->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given module_name.
     *
     * @param UserPolicy $user
     * @param ModuleName $module_name
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ModuleName $module_name)
    {
        return $module_name->user_id == user_id() && $module_name->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given module_name.
     *
     * @param UserPolicy $user
     * @param ModuleName $module_name
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ModuleName $module_name)
    {
        if ($user->canDo('package.module_name.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given module_name.
     *
     * @param UserPolicy $user
     * @param ModuleName $module_name
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ModuleName $module_name)
    {
        if ($user->canDo('package.module_name.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
