<?php

namespace Provider\Package\Providers;

use Illuminate\Support\ServiceProvider;

class PackageServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'package');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'package');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('provider.package', function ($app) {
            return $this->app->make('Provider\Package\Package');
        });

                // Bind ModuleName to repository
        $this->app->bind(
            'Provider\Package\Interfaces\ModuleNameRepositoryInterface',
            \Provider\Package\Repositories\Eloquent\ModuleNameRepository::class
        );

        $this->app->register(\Provider\Package\Providers\AuthServiceProvider::class);
                $this->app->register(\Provider\Package\Providers\EventServiceProvider::class);
        
        $this->app->register(\Provider\Package\Providers\RouteServiceProvider::class);
                $this->app->register(\Provider\Package\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['provider.package'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('provider/package.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/package')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/package')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
