<?php

namespace Provider\Package\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Provider\Package\Models\ModuleName;

class ModuleNameAction
{
    /**
     * Perform the complete action.
     *
     * @param ModuleName $module_name
     *
     * @return ModuleName
     */
    public function complete(ModuleName $module_name)
    {
        try {
            $module_name->status = 'complete';
            return $module_name->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ModuleName $module_name
     *
     * @return ModuleName
     */public function verify(ModuleName $module_name)
    {
        try {
            $module_name->status = 'verify';
            return $module_name->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ModuleName $module_name
     *
     * @return ModuleName
     */public function approve(ModuleName $module_name)
    {
        try {
            $module_name->status = 'approve';
            return $module_name->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ModuleName $module_name
     *
     * @return ModuleName
     */public function publish(ModuleName $module_name)
    {
        try {
            $module_name->status = 'publish';
            return $module_name->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ModuleName $module_name
     *
     * @return ModuleName
     */
    public function archive(ModuleName $module_name)
    {
        try {
            $module_name->status = 'archive';
            return $module_name->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ModuleName $module_name
     *
     * @return ModuleName
     */
    public function unpublish(ModuleName $module_name)
    {
        try {
            $module_name->status = 'unpublish';
            return $module_name->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
