<?php

namespace Provider\Package\Workflow;

use Provider\Package\Models\ModuleName;
use Validator;

class ModuleNameValidator
{

    /**
     * Determine if the given module_name is valid for complete status.
     *
     * @param ModuleName $module_name
     *
     * @return bool / Validator
     */
    public function complete(ModuleName $module_name)
    {
        return Validator::make($module_name->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given module_name is valid for verify status.
     *
     * @param ModuleName $module_name
     *
     * @return bool / Validator
     */
    public function verify(ModuleName $module_name)
    {
        return Validator::make($module_name->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given module_name is valid for approve status.
     *
     * @param ModuleName $module_name
     *
     * @return bool / Validator
     */
    public function approve(ModuleName $module_name)
    {
        return Validator::make($module_name->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given module_name is valid for publish status.
     *
     * @param ModuleName $module_name
     *
     * @return bool / Validator
     */
    public function publish(ModuleName $module_name)
    {
        return Validator::make($module_name->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given module_name is valid for archive status.
     *
     * @param ModuleName $module_name
     *
     * @return bool / Validator
     */
    public function archive(ModuleName $module_name)
    {
        return Validator::make($module_name->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given module_name is valid for unpublish status.
     *
     * @param ModuleName $module_name
     *
     * @return bool / Validator
     */
    public function unpublish(ModuleName $module_name)
    {
        return Validator::make($module_name->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
